@@ -48,7 +48,10 @@ impl Error {
 
 impl From<Error> for ockam_core::Error {
     fn from(e: Error) -> ockam_core::Error {
-        ockam_core::Error::new(Error::DOMAIN_CODE + (e as u32), Error::DOMAIN_NAME)
+        ockam_core::Error::new(
+            Error::DOMAIN_CODE + (e as u32),
+            ockam_core::compat::format!("{}::{:?}", module_path!(), e),
+        )
     }
 }
 
