@@ -35,7 +35,6 @@ pub mod compat;
 mod cancel;
 mod context;
 mod delayed;
-mod error;
 mod executor;
 mod messages;
 mod node;
@@ -43,6 +42,9 @@ mod parser;
 mod relay;
 mod router;
 
+/// Errors
+pub mod error;
+
 pub use cancel::*;
 pub use context::*;
 pub use delayed::*;
