@@ -6,6 +6,7 @@ use crate::tokio::sync::mpsc::Sender;
 pub enum NodeState {
     Running,
     Stopping(Sender<NodeReplyResult>),
+    Dead,
 }
 
 pub struct RouterState {
@@ -26,6 +27,11 @@ impl RouterState {
         self.node_state = NodeState::Stopping(reply)
     }
 
+    /// Ungracefully kill the router
+    pub(super) fn kill(&mut self) {
+        self.node_state = NodeState::Dead;
+    }
+
     pub(super) fn stop_reply(&self) -> Option<Sender<NodeReplyResult>> {
         match &self.node_state {
             NodeState::Stopping(sender) => Some(sender.clone()),
