@@ -11,9 +11,8 @@ pub(super) async fn exec(
 ) -> Result<()> {
     trace!("Stopping worker '{}'", addr);
 
-    let primary_address;
-    if let Some(p) = router.map.addr_map.get(addr) {
-        primary_address = p.clone();
+    let primary_address = if let Some(p) = router.map.addr_map.get(addr) {
+        p.clone()
     } else {
         reply
             .send(NodeReply::no_such_address(addr.clone()))
@@ -21,11 +20,10 @@ pub(super) async fn exec(
             .map_err(|_| Error::InternalIOFailure)?;
 
         return Ok(());
-    }
+    };
 
-    let record;
-    if let Some(r) = router.map.internal.remove(&primary_address) {
-        record = r;
+    let record = if let Some(r) = router.map.internal.remove(&primary_address) {
+        r
     } else {
         // Actually should not happen
         reply
@@ -34,7 +32,7 @@ pub(super) async fn exec(
             .map_err(|_| Error::InternalIOFailure)?;
 
         return Ok(());
-    }
+    };
 
     for addr in record.address_set().iter() {
         router.map.addr_map.remove(addr);
